@@ -1,9 +1,11 @@
+import socket
+import asyncio
+import warnings
+
 from aiohttp import ClientSession, CookieJar
 from sanic.server import serve, HttpProtocol
 from inspect import isawaitable
 from sanic.app import Sanic
-import socket
-import asyncio
 
 
 HEAD = 'HEAD'
@@ -40,8 +42,12 @@ class TestServer:
                  **kwargs):
         if not isinstance(app, Sanic):
             raise TypeError("app should be a Sanic application.")
+        if loop:
+            warnings.warn("passing through `loop` is deprecated.",
+                          DeprecationWarning,
+                          stacklevel=2)
         self.app = app
-        self.loop = loop
+        self.loop = loop or asyncio.get_event_loop()
         self.host = host
         self.protocol = protocol or HttpProtocol
         self.backlog = backlog
@@ -67,9 +73,7 @@ class TestServer:
         self.closed = None
         self.is_running = False
 
-    async def start_server(self, loop=None):
-        if loop:
-            self.loop = loop
+    async def start_server(self):
         self.socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         self.socket.bind((self.host, 0))
         self.port = self.socket.getsockname()[1]
@@ -128,7 +132,7 @@ class TestServer:
                     coros.append(conn.websocket.close_connection())
                 else:
                     conn.close()
-            await asyncio.gather(*coros, loop=self.loop)
+            await asyncio.gather(*coros)
 
             # Trigger after_stop events
             await trigger_events(self.after_server_stop, self.loop)
@@ -167,8 +171,12 @@ class TestClient:
                  **kwargs):
         if not isinstance(app, Sanic):
             raise TypeError("app should be a Sanic application.")
+
+        if loop:
+            warnings.warn("passing through `loop` is deprecated.",
+                          DeprecationWarning,
+                          stacklevel=2)
         self._app = app
-        self._loop = loop
         # we should use '127.0.0.1' in most cases.
         self._host = host
         self._ssl = ssl
@@ -176,12 +184,11 @@ class TestClient:
         self._protocol = HttpProtocol if protocol is None else protocol
         self._closed = False
         self._server = TestServer(
-                    self._app, loop=self._loop,
+                    self._app, loop=loop,
                     protocol=self._protocol, ssl=self._ssl,
                     scheme=self._scheme)
-        cookie_jar = CookieJar(unsafe=True, loop=loop)
-        self._session = ClientSession(loop=loop,
-                                      cookie_jar=cookie_jar,
+        cookie_jar = CookieJar(unsafe=True)
+        self._session = ClientSession(cookie_jar=cookie_jar,
                                       **kwargs)
         # Let's collect responses objects and websocket objects,
         # and clean up when test is done.
@@ -215,7 +222,7 @@ class TestClient:
         """
         Start a TestServer that running Sanic application.
         """
-        await self._server.start_server(loop=self._loop)
+        await self._server.start_server()
 
     async def close(self):
         """
